@@ -1,5 +1,6 @@
-
 import glob
+import sys
+sys.path.insert(0, ".")
 import os
 import shutil
 import solfege.languages
@@ -14,15 +15,6 @@ for lang in gtk_po:
     if os.path.split(lang)[-1] not in sol_po:
         shutil.rmtree(lang)
 
-shutil.rmtree(r"win32\python\Lib\test")
-shutil.rmtree(r"win32\python\Lib\curses")
-shutil.rmtree(r"win32\share\applications")
-shutil.rmtree(r"win32\share\man")
-shutil.rmtree(r"win32\python\Doc")
-shutil.rmtree(r"win32\python\tcl")
-shutil.rmtree(r"win32\python\Tools")
-shutil.rmtree(r"win32\test")
-shutil.rmtree(r"win32\include")
 shutil.rmtree(r"win32\python\include")
 for fn in glob.glob("win32/share/locale/*"):
     if not os.path.split(fn)[1] in solfege.languages.languages:
